pyxmpp2.mainloop.poll.PollMainLoop

Package pyxmpp2 :: Package mainloop :: Module poll :: Class PollMainLoop |
[hide private]

# Class PollMainLoop

Main event loop based on the poll() syscall.

Nested Classes | [hide private]
Inherited from `interfaces.MainLoop`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, settings=None, handlers=None) x.__init__(...) initializes x; see help(type(x)) for signature |
_add_io_handler(self, handler) Add an I/O handler to the loop. |
_configure_io_handler(self, handler) Register an io-handler at the polling object. |
_prepare_io_handler(self, handler) Call the interfaces.IOHandler.prepare method and remove the handler from unprepared handler list when done. |
_remove_io_handler(self, handler) Remove an i/o-handler. |
loop_iteration(self, timeout=60) A loop iteration - check any scheduled events and I/O available and run the handlers. |
Inherited from `base.MainLoopBase`: `add_handler`, `check_events`, `loop`, `quit`, `remove_handler` Inherited from `base.MainLoopBase` (private): `_add_timeout_handler`, `_call_timeout_handlers`, `_remove_timeout_handler` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `interfaces.MainLoop`: `__abstractmethods__` Inherited from `interfaces.MainLoop` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `base.MainLoopBase`: `finished`, `started` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, settings=None, handlers=None) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### _add_io_handler(self, handler) |
Add an I/O handler to the loop. Overrides: base.MainLoopBase._add_io_handler

### _remove_io_handler(self, handler) |
Remove an i/o-handler. Overrides: base.MainLoopBase._remove_io_handler

### loop_iteration(self, timeout=60) |
A loop iteration - check any scheduled events and I/O available and run the handlers. Parameters: `timeout` - maximum time (in seconds) to block for Overrides: interfaces.MainLoop.loop_iteration